@@ -8,7 +8,11 @@ use warnings;
 
 sub pp_method_named {
     my $self = shift;
-    $self->op->meth_sv->PV;
+
+    my $sv = $self->op->meth_sv;
+    $sv = $self->_padval_sv($self->op->targ) unless $$sv;  # happens in thread-enabled perls
+
+    $sv->PV;
 }
 
 1;
